bayespy.inference.vmp.nodes.binomial.BinomialMoments.compute_fixed_moments
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialMoments.compute_fixed_moments